restVelocityThreshold property
Rest velocity threshold below which motion is considered stopped.
Implementation
final double restVelocityThreshold;
Rest velocity threshold below which motion is considered stopped.
final double restVelocityThreshold;