endPosition property
Position at which the simulation is considered done (floor/ceiling). Set to double.maxFinite to never stop.
Implementation
final double endPosition;
Position at which the simulation is considered done (floor/ceiling). Set to double.maxFinite to never stop.
final double endPosition;