AnimatableProperty enum
All CSS/Flutter-equivalent properties that can be animated.
- Inheritance
- Available extensions
Values
- opacity → const AnimatableProperty
- translateX → const AnimatableProperty
- translateY → const AnimatableProperty
- translateZ → const AnimatableProperty
- scale → const AnimatableProperty
- scaleX → const AnimatableProperty
- scaleY → const AnimatableProperty
- rotate → const AnimatableProperty
- rotateX → const AnimatableProperty
- rotateY → const AnimatableProperty
- skewX → const AnimatableProperty
- skewY → const AnimatableProperty
- blur → const AnimatableProperty
- saturation → const AnimatableProperty
- brightness → const AnimatableProperty
- hue → const AnimatableProperty
- contrast → const AnimatableProperty
- borderRadius → const AnimatableProperty
- clipPath → const AnimatableProperty
- width → const AnimatableProperty
- height → const AnimatableProperty
- padding → const AnimatableProperty
- margin → const AnimatableProperty
- color → const AnimatableProperty
- backgroundColor → const AnimatableProperty
- borderColor → const AnimatableProperty
- elevation → const AnimatableProperty
- shadow → const AnimatableProperty
- custom → const AnimatableProperty
Properties
- affectsLayout → bool
-
Available on AnimatableProperty, provided by the AnimatablePropertyX extension
True if this property affects layout (may trigger relayout).no setter - cssName → String
-
Available on AnimatableProperty, provided by the AnimatablePropertyX extension
Human-readable CSS-like name.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- is3D → bool
-
Available on AnimatableProperty, provided by the AnimatablePropertyX extension
True if this property requires 3D perspective setup.no setter - isExpensive → bool
-
Available on AnimatableProperty, provided by the AnimatablePropertyX extension
True if this property requires expensive GPU operations. Used by FrameBudgeter to disable effects under FPS threshold.no setter - isPaintOnly → bool
-
Available on AnimatableProperty, provided by the AnimatablePropertyX extension
True if this property only affects the paint layer (no relayout).no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AnimatableProperty> - A constant List of the values in this enum, in order of their declaration.